@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Maven::Maven;
-$Maven::Maven::VERSION = '1.11';
+$Maven::Maven::VERSION = '1.12';
 # ABSTRACT: The main interface to maven
 # PODNAME: Maven::Maven
 
@@ -63,11 +63,10 @@ sub _init {
         'user.home' => $options{'user.home'} || _default_user_home()
     };
 
-    $self->{settings} = load_settings(
-        $self->m2_home( 'conf', 'settings.xml' ),
-        $self->dot_m2('settings.xml'),
-        $self->{properties}
-    );
+    my $global_settings = $self->m2_home( 'conf', 'settings.xml' );
+    my $user_settings = $self->dot_m2('settings.xml');
+    $self->{settings} =
+        load_settings( [ $global_settings, $user_settings ], $self->{properties} );
 
     # some day we should load pom...
 
@@ -171,6 +170,7 @@ sub _load_active_profiles {
 
 sub m2_home {
     my ( $self, @parts ) = @_;
+    return unless ( $self->{properties}{'env.M2_HOME'} );
     return File::Spec->catdir( $self->{properties}{'env.M2_HOME'}, @parts );
 }
 
@@ -191,7 +191,7 @@ Maven::Maven - The main interface to maven
 
 =head1 VERSION
 
-version 1.11
+version 1.12
 
 =head1 SYNOPSIS
 
